@@ -5,7 +5,10 @@
 #include "cut-public.h"
 #include "cut-private.h"
 #include "cut-runner.h"
+#include "cut-run-context.h"
+#include "cut-test-runner.h"
 #include "cut-listener.h"
+#include "cut-listener-utils.h"
 #include "cut-main.h"
 #include "cut-test.h"
 #include "cut-test-case.h"
@@ -17,12 +20,15 @@
 #include "cut-contractor.h"
 #include "cut-factory-builder.h"
 #include "cut-report-factory-builder.h"
+#include "cut-streamer-factory-builder.h"
 #include "cut-ui-factory-builder.h"
 #include "cut-module-factory.h"
 #include "cut-module-factory-utils.h"
 #include "cut-report.h"
+#include "cut-streamer.h"
 #include "cut-process.h"
-#include "cut-xml-parser.h"
+#include "cut-pipeline.h"
+#include "cut-stream-parser.h"
 #include "cut-verbose-level.h"
 #include "cut-sequence-matcher.h"
 #include "cut-diff.h"
