@@ -40,12 +40,19 @@
 #define ATTRIBUTE_PREFIX "attributes_"
 #define CUT_LOADER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_LOADER, CutLoaderPrivate))
 
+typedef enum {
+    CUT_BINARY_TYPE_UNKNOWN,
+    CUT_BINARY_TYPE_MACH_O_BUNDLE,
+    CUT_BINARY_TYPE_MS_WINDOWS_DLL
+} CutBinaryType;
+
 typedef struct _CutLoaderPrivate	CutLoaderPrivate;
 struct _CutLoaderPrivate
 {
     gchar *so_filename;
     GList *symbols;
     GModule *module;
+    CutBinaryType binary_type;
 };
 
 enum
@@ -94,6 +101,7 @@ cut_loader_init (CutLoader *loader)
     CutLoaderPrivate *priv = CUT_LOADER_GET_PRIVATE(loader);
 
     priv->so_filename = NULL;
+    priv->binary_type = CUT_BINARY_TYPE_UNKNOWN;
 }
 
 static void
@@ -177,6 +185,16 @@ is_test_function_name (const gchar *name)
 }
 
 #ifdef HAVE_LIBBFD
+
+gboolean
+cut_loader_support_attribute (CutLoader *loader)
+{
+    CutLoaderPrivate *priv;
+
+    priv = CUT_LOADER_GET_PRIVATE(loader);
+    return priv->binary_type != CUT_BINARY_TYPE_MACH_O_BUNDLE;
+}
+
 static GList *
 collect_symbols (CutLoaderPrivate *priv)
 {
@@ -185,6 +203,7 @@ collect_symbols (CutLoaderPrivate *priv)
     asymbol **symbol_table;
     long number_of_symbols;
     long i;
+    char symbol_leading_char;
     bfd *abfd;
 
     abfd = bfd_openr(priv->so_filename, NULL);
@@ -205,12 +224,22 @@ collect_symbols (CutLoaderPrivate *priv)
     symbol_table = (asymbol **)g_new(char, storage_needed);
     number_of_symbols = bfd_canonicalize_symtab(abfd, symbol_table);
 
+    symbol_leading_char = bfd_get_symbol_leading_char(abfd);
+    if (bfd_get_flavour(abfd) == bfd_target_mach_o_flavour)
+        priv->binary_type = CUT_BINARY_TYPE_MACH_O_BUNDLE;
+
     for (i = 0; i < number_of_symbols; i++) {
         symbol_info info;
 
         bfd_symbol_info(symbol_table[i], &info);
-        if (info.type == 'T') {
-            symbols = g_list_prepend(symbols, g_strdup(info.name));
+        if (info.type == 'T' ||
+            (priv->binary_type == CUT_BINARY_TYPE_MACH_O_BUNDLE &&
+             info.type == 'U')) {
+            const char *name = info.name;
+
+            while (symbol_leading_char == name[0])
+                name++;
+            symbols = g_list_prepend(symbols, g_strdup(name));
         }
     }
 
@@ -222,16 +251,25 @@ collect_symbols (CutLoaderPrivate *priv)
 
 #else
 
-typedef enum {
-    CUT_BINARY_TYPE_UNKNOWN,
-    CUT_BINARY_TYPE_MACH_O_BUNDLE
-} CutBinaryType;
+gboolean
+cut_loader_support_attribute (CutLoader *loader)
+{
+    CutLoaderPrivate *priv;
+
+    priv = CUT_LOADER_GET_PRIVATE(loader);
+    return priv->binary_type == CUT_BINARY_TYPE_MS_WINDOWS_DLL;
+}
 
 static inline CutBinaryType
 guess_binary_type (char *buffer, size_t size)
 {
-    if (size >= 4 && ((unsigned int *)buffer)[0] == 0xfeedface)
+    if (size >= 4 && ((guint32 *)buffer)[0] == 0xfeedface)
         return CUT_BINARY_TYPE_MACH_O_BUNDLE;
+    if (size >= 4 &&
+        ((guint8 *)buffer)[0] == 'M' &&
+        ((guint8 *)buffer)[1] == 'Z' &&
+        ((guint8 *)buffer)[4] & 0x2)
+        return CUT_BINARY_TYPE_MS_WINDOWS_DLL;
     return CUT_BINARY_TYPE_UNKNOWN;
 }
 
@@ -253,7 +291,7 @@ is_valid_char_for_cutter_symbol (GString *name, char *buffer,
 static inline gboolean
 is_valid_symbol_name (GString *name)
 {
-    return name->len > 1;
+    return name->len >= 4;
 }
 
 static GList *
@@ -266,7 +304,6 @@ collect_symbols (CutLoaderPrivate *priv)
     GHashTable *symbol_name_table;
     GList *symbols;
     gboolean first_buffer = TRUE;
-    CutBinaryType binary_type = CUT_BINARY_TYPE_UNKNOWN;
 
     input = g_fopen(priv->so_filename, "rb");
     if (!input)
@@ -278,13 +315,13 @@ collect_symbols (CutLoaderPrivate *priv)
         size_t i;
 
         if (first_buffer) {
-            binary_type = guess_binary_type(buffer, size);
+            priv->binary_type = guess_binary_type(buffer, size);
             first_buffer = FALSE;
         }
 
         for (i = 0; i < size; i++) {
             if (is_valid_char_for_cutter_symbol(name, buffer, i,
-                                                size, binary_type)) {
+                                                size, priv->binary_type)) {
                 g_string_append_c(name, buffer[i]);
             } else if (name->len > 0) {
                 if (is_valid_symbol_name(name)) {
@@ -341,7 +378,7 @@ static gboolean
 is_valid_attributes_function_name (const gchar *function_name, const gchar *test_name)
 {
     return g_str_has_prefix(function_name, ATTRIBUTE_PREFIX) &&
-           is_including_test_name(function_name, test_name);
+        is_including_test_name(function_name, test_name);
 }
 
 static gchar *
@@ -349,7 +386,8 @@ get_attribute_name (const gchar *attribute_function_name, const gchar *test_name
 {
     gchar *pos;
 
-    pos = g_strrstr(attribute_function_name, test_name + strlen(TEST_NAME_PREFIX)) - 1;
+    pos = g_strrstr(attribute_function_name,
+                    test_name + strlen(TEST_NAME_PREFIX)) - 1;
 
     return g_strndup(attribute_function_name, pos - attribute_function_name);
 }
@@ -397,7 +435,8 @@ collect_attributes (CutLoaderPrivate *priv, const gchar *test_name)
                     CutTestAttribute *new_attribute;
                     if (!attribute->name || !attribute->value)
                         break;
-                    new_attribute = cut_test_attribute_new(attribute->name, attribute->value);
+                    new_attribute = cut_test_attribute_new(attribute->name,
+                                                           attribute->value);
                     attributes = g_list_append(attributes, new_attribute);
                     attribute++;
                 }
@@ -481,8 +520,9 @@ cut_loader_load_test_case (CutLoader *loader)
     GList *node;
     GList *test_names;
     CutTestCase *test_case;
-    CutLoaderPrivate *priv = CUT_LOADER_GET_PRIVATE(loader);
+    CutLoaderPrivate *priv;
 
+    priv = CUT_LOADER_GET_PRIVATE(loader);
     if (!priv->so_filename)
         return NULL;
 
@@ -508,9 +548,10 @@ cut_loader_load_test_case (CutLoader *loader)
         name = node->data;
         g_module_symbol(priv->module, name, (gpointer)&function);
         if (function) {
-            GList *attributes;
+            GList *attributes = NULL;
             test = cut_test_new(name, function);
-            attributes = collect_attributes(priv, name);
+            if (cut_loader_support_attribute(loader))
+                attributes = collect_attributes(priv, name);
             if (attributes) {
                 set_attributes(test, attributes);
             }
