@@ -24,6 +24,8 @@
 #  error "don't include cutter.h with test runner program!"
 #endif
 
+#include <cutter/cut-version.h>
+
 #include <cutter/cut-test-runner.h>
 #include <cutter/cut-test-suite.h>
 
@@ -34,6 +36,9 @@ void          cut_quit               (void);
 
 gboolean      cut_run                (void);
 
+void          cut_set_cutter_command_path (const char *argv0);
+const char   *cut_get_cutter_command_path (void);
+
 CutRunContext *cut_create_run_context(void);
 gboolean       cut_start_run_context (CutRunContext *run_context);
 
