@@ -33,7 +33,7 @@ G_BEGIN_DECLS
 #define CUT_IS_TEST_CASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CUT_TYPE_TEST_CASE))
 #define CUT_TEST_CASE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), CUT_TYPE_TEST_CASE, CutTestCaseClass))
 
-typedef void (*CutStartupFunction) (void);
+typedef void (*CutStartupFunction)    (void);
 typedef void (*CutShutdownFunction)   (void);
 
 typedef struct _CutTestCaseClass CutTestCaseClass;
@@ -60,16 +60,14 @@ struct _CutTestCaseClass
 GType        cut_test_case_get_type       (void) G_GNUC_CONST;
 
 CutTestCase *cut_test_case_new            (const gchar *name,
-                                           CutSetupFunction setup_function,
-                                           CutTeardownFunction teardown_function,
+                                           CutSetupFunction setup,
+                                           CutTeardownFunction teardown,
                                            CutGetCurrentTestContextFunction
-                                           get_current_test_context_function,
+                                           get_current_test_context,
                                            CutSetCurrentTestContextFunction
-                                           set_current_test_context_function,
-                                           CutStartupFunction
-                                           startup_function,
-                                           CutShutdownFunction
-                                           shutdown_function);
+                                           set_current_test_context,
+                                           CutStartupFunction startup,
+                                           CutShutdownFunction shutdown);
 CutTestCase *cut_test_case_new_empty      (void);
 void         cut_test_case_add_test       (CutTestCase *test_case,
                                            CutTest *test);
