@@ -25,8 +25,12 @@
 #include <string.h>
 #include <setjmp.h>
 #include <sys/types.h>
-#include <sys/wait.h>
-#include <unistd.h>
+#ifdef HAVE_SYS_WAIT_H
+#  include <sys/wait.h>
+#endif
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
 #include <glib.h>
 
 #include "cut-test-context.h"
@@ -35,6 +39,17 @@
 #include "cut-process.h"
 #include "cut-utils.h"
 
+#define cut_omit(context, message, ...) do                      \
+{                                                               \
+    cut_test_context_register_result(context,                   \
+                                     CUT_TEST_RESULT_OMISSION,  \
+                                     __PRETTY_FUNCTION__,       \
+                                     __FILE__, __LINE__,        \
+                                     message, ## __VA_ARGS__,   \
+                                     NULL);                     \
+    cut_test_context_long_jump(context);                        \
+} while (0)
+
 #define CUT_TEST_CONTEXT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_TEST_CONTEXT, CutTestContextPrivate))
 
 typedef struct _CutTestContextPrivate	CutTestContextPrivate;
@@ -53,6 +68,8 @@ struct _CutTestContextPrivate
     gpointer user_data;
     GDestroyNotify user_data_destroy_notify;
     GList *processes;
+    gchar *fixture_data_dir;
+    GHashTable *cached_fixture_data;
 };
 
 enum
@@ -133,6 +150,10 @@ cut_test_context_init (CutTestContext *context)
     priv->user_data_destroy_notify = NULL;
 
     priv->processes = NULL;
+
+    priv->fixture_data_dir = NULL;
+    priv->cached_fixture_data = g_hash_table_new_full(g_str_hash, g_str_equal,
+                                                      g_free, g_free);
 }
 
 static void
@@ -187,6 +208,16 @@ dispose (GObject *object)
         priv->user_data_destroy_notify(priv->user_data);
     priv->user_data = NULL;
 
+    if (priv->fixture_data_dir) {
+        g_free(priv->fixture_data_dir);
+        priv->fixture_data_dir = NULL;
+    }
+
+    if (priv->cached_fixture_data) {
+        g_hash_table_unref(priv->cached_fixture_data);
+        priv->cached_fixture_data = NULL;
+    }
+
     G_OBJECT_CLASS(cut_test_context_parent_class)->dispose(object);
 }
 
@@ -530,6 +561,12 @@ cut_test_context_trap_fork (CutTestContext *context,
                             const gchar *filename,
                             guint line)
 {
+#ifdef G_OS_WIN32
+    cut_omit(context,
+             "cut_test_context_wait_process() doesn't "
+             "work on the environment.");
+    return 0;
+#else
     CutTestContextPrivate *priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
     CutProcess *process;
 
@@ -547,6 +584,7 @@ cut_test_context_trap_fork (CutTestContext *context,
     priv->processes = g_list_prepend(priv->processes, process);
 
     return cut_process_fork(process);
+#endif
 }
 
 int
@@ -554,6 +592,11 @@ cut_test_context_wait_process (CutTestContext *context,
                                int pid, unsigned int timeout)
 {
     int exit_status = EXIT_SUCCESS;
+#ifdef G_OS_WIN32
+    cut_omit(context,
+             "cut_test_context_wait_process() doesn't "
+             "work on the environment.");
+#else
     CutProcess *process;
 
     process = get_process_from_pid(context, pid);
@@ -587,7 +630,7 @@ cut_test_context_wait_process (CutTestContext *context,
                 xml += result_xml_length;
         }
     }
-
+#endif
     return exit_status;
 }
 
@@ -666,6 +709,114 @@ cut_test_context_to_xml_string (CutTestContext *context, GString *string,
     g_string_append(string, "</test-context>\n");
 }
 
+void
+cut_test_context_set_fixture_data_dir (CutTestContext *context,
+                                       const gchar *path, ...)
+{
+    CutTestContextPrivate *priv;
+    va_list args;
+
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+    if (priv->fixture_data_dir)
+        g_free(priv->fixture_data_dir);
+
+    va_start(args, path);
+    priv->fixture_data_dir = cut_utils_expand_pathv(path, &args);
+    va_end(args);
+}
+
+gchar *
+cut_test_context_build_fixture_data_pathv (CutTestContext *context,
+                                           const gchar *path, va_list *args)
+{
+    CutTestContextPrivate *priv;
+    gchar *concatenated_path, *full_path;
+
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+
+    concatenated_path = cut_utils_build_pathv(path, args);
+    if (g_path_is_absolute(concatenated_path)) {
+        full_path = concatenated_path;
+    } else {
+        if (priv->fixture_data_dir) {
+            full_path = g_build_filename(priv->fixture_data_dir,
+                                         concatenated_path,
+                                         NULL);
+        } else {
+            full_path = cut_utils_expand_path(concatenated_path);
+        }
+        g_free(concatenated_path);
+    }
+
+    return full_path;
+}
+
+gchar *
+cut_test_context_build_fixture_data_path (CutTestContext *context,
+                                          const gchar *path, ...)
+{
+    va_list args;
+    gchar *full_path;
+
+    va_start(args, path);
+    full_path = cut_test_context_build_fixture_data_pathv(context, path, &args);
+    va_end(args);
+
+    return full_path;
+}
+
+const gchar *
+cut_test_context_get_fixture_data_stringv (CutTestContext *context,
+                                           GError **error,
+                                           const gchar *path,
+                                           va_list *args)
+{
+    CutTestContextPrivate *priv;
+    gchar *full_path;
+    gpointer value;
+
+    if (!path)
+        return NULL;
+
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+
+    full_path = cut_test_context_build_fixture_data_pathv(context, path, args);
+    value = g_hash_table_lookup(priv->cached_fixture_data, full_path);
+    if (value) {
+        g_free(full_path);
+    } else {
+        gchar *contents;
+        gsize length;
+
+        if (g_file_get_contents(full_path, &contents, &length, error)) {
+            g_hash_table_insert(priv->cached_fixture_data, full_path, contents);
+            value = contents;
+        } else {
+            g_free(full_path);
+        }
+    }
+
+    return value;
+}
+
+const gchar *
+cut_test_context_get_fixture_data_string (CutTestContext *context,
+                                          GError **error,
+                                          const gchar *path, ...)
+{
+    const gchar *value;
+    va_list args;
+
+    if (!path)
+        return NULL;
+
+    va_start(args, path);
+    value = cut_test_context_get_fixture_data_stringv(context, error,
+                                                      path, &args);
+    va_end(args);
+
+    return value;
+}
 
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
