@@ -15,6 +15,13 @@ static CutTest *test;
 static CutLoader *test_loader;
 static CutTestCase *test_case;
 
+#define cut_omit_if_loader_does_not_support_attribute(loader) do        \
+{                                                                       \
+    if (!cut_loader_support_attribute(loader))                          \
+        cut_omit("test attribute loading isn't "                        \
+                 "supported on the environment.");                      \
+} while (0)
+
 static void
 fail_test (void)
 {
@@ -29,7 +36,7 @@ setup (void)
     test_path = g_build_filename(cuttest_get_base_dir(),
                                  "attribute_test_dir",
                                  ".libs",
-                                 "dummy_attribute_test.so",
+                                 "dummy_attribute_test." G_MODULE_SUFFIX,
                                  NULL);
     test_loader = cut_loader_new(test_path);
     g_free(test_path);
@@ -75,9 +82,13 @@ test_get_bug_id (void)
     container = CUT_TEST_CONTAINER(test_case);
     tests = cut_test_container_filter_children(container, filter);
     cut_assert(tests);
-
     cut_assert(1, g_list_length(tests));
-    cut_assert_equal_string("1234567890", cut_test_get_attribute(CUT_TEST(tests->data), "bug"));
+
+    cut_omit_if_loader_does_not_support_attribute(test_loader);
+
+    cut_assert_equal_string("1234567890",
+                            cut_test_get_attribute(CUT_TEST(tests->data),
+                                                   "bug"));
 }
 
 void
@@ -93,12 +104,16 @@ test_get_attribute (void)
     container = CUT_TEST_CONTAINER(test_case);
     tests = cut_test_container_filter_children(container, filter);
     cut_assert(tests);
-
     cut_assert(1, g_list_length(tests));
-    cut_assert_equal_string("9", cut_test_get_attribute(CUT_TEST(tests->data),
-                                                        "bug"));
-    cut_assert_equal_string("5678", cut_test_get_attribute(CUT_TEST(tests->data),
-                                                           "priority"));
+
+    cut_omit_if_loader_does_not_support_attribute(test_loader);
+
+    cut_assert_equal_string("9",
+                            cut_test_get_attribute(CUT_TEST(tests->data),
+                                                   "bug"));
+    cut_assert_equal_string("5678",
+                            cut_test_get_attribute(CUT_TEST(tests->data),
+                                                   "priority"));
 }
 
 void
@@ -114,9 +129,11 @@ test_get_description (void)
     container = CUT_TEST_CONTAINER(test_case);
     tests = cut_test_container_filter_children(container, filter);
     cut_assert(tests);
-
     cut_assert(1, g_list_length(tests));
-    cut_assert_equal_string("This message is the description of test_description()", 
+
+    cut_omit_if_loader_does_not_support_attribute(test_loader);
+
+    cut_assert_equal_string("This message is the description of test_description()",
                             cut_test_get_description(CUT_TEST(tests->data)));
 }
 
